### MR Acceptance Checklist

- [ ] Code follows [Semantic Versioning](https://semver.org/) conventions for release versioning.
- [ ] Documentation reflects the changes that were made since the last release.
- [ ] Changes have been documented in the CHANGELOG.md following [Keep a Changelog](https://keepachangelog.com/en/1.1.0/) conventions.

<!-- template sourced from https://gitlab.com/gitlab-org/gitlab/-/blob/master/.gitlab/merge_request_templates/Default.md -->

/assign me
